poll

Function poll 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn poll( fds: *mut pollfd, nfds: nfds_t, timeout: c_int, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/poll.html.

Provides applications with a mechanism for multiplexing input/output over a set of file descriptors.

  • The timeout parameter represents milliseconds.
  • A timeout of -1 is equivalent to passing a null pointer for tmo_p to ppoll.
  • poll should behave equivalent to ppoll with a null pointer for sigmask.

Note: Uses epoll internally.