ppoll

Function ppoll 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn ppoll( fds: *mut pollfd, nfds: nfds_t, tmo_p: *const timespec, sigmask: *const sigset_t, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/ppoll.html.

Provides applications with a mechanism for multiplexing input/output over a set of file descriptors.

  • The tmo_p parameter is the timeout as represented by a timespec struct.
  • Passing a null pointer for timeout is equivalent to -1 for timeout to poll.

Note: Uses epoll internally.